.. _gaplic_module:

-----------------------
:mod:`ginsfsm.gaplic`
-----------------------

.. automodule:: ginsfsm.gaplic

.. autoclass:: GAplic
    :members: create_gobj, destroy_gobj,
        register_gobj, deregister_gobj, search_gobj,
        mt_process, mt_subprocess

.. autofunction:: start_gaplic_thread

.. autoclass:: GAplicThreadWorker
    :members:

.. autofunction:: start_gaplic_process

.. autoclass:: GAplicProcessWorker
    :members:
